{% import 'appbuilder/baselib.html' as baselib with context %}

{% if baseapp %}
	{% set lst_menu = baseapp.menu.get_list() %}
	{% set app_name = baseapp.app_name %}
{% endif %}

<!DOCTYPE html>
<html>
  <head>
    <title>{{app_name}}</title>

<!-- HTML5 shim, for IE6-8 support of HTML5 elements -->
 <!--[if lt IE 9]>
     <script src="{{url_for('baseapp.static',filename='js/html5shiv.js')}}"></script>
     <script src="{{url_for('baseapp.static',filename='js/respond.js')}}"></script>
 <![endif]-->
 
    {% block head_meta %}
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <meta name="description" content="">
        <meta name="author" content="">
    {% endblock %}
    {% block head_css %}
	<link rel="stylesheet" href="//netdna.bootstrapcdn.com/bootstrap/3.0.0/css/bootstrap.min.css">
        <link href="{{url_for('baseapp.static',filename='css/themes/'+ baseapp.app_theme )}}"  rel="stylesheet">
	<link href="{{url_for('baseapp.static',filename='datepicker/bootstrap-datepicker.css')}}" rel="stylesheet">
	<link href="{{url_for('baseapp.static',filename='select2/select2.css')}}" rel="stylesheet">
        <link href="{{url_for('baseapp.static',filename='css/flags/flags16.css')}}" rel="stylesheet">
        <style>
        </style>
    {% endblock %}

</head>

<body>

{% block navbar %}
{{ baselib.navbar_block(app_name, lst_menu, baseapp.languages) }}
{% endblock %}

{% block body %}
{% endblock %}

{% block tail_js %}
	<script src="http://code.jquery.com/jquery-latest.js"></script>
	<script src="//netdna.bootstrapcdn.com/bootstrap/3.0.0/js/bootstrap.min.js"></script>
	<script src="{{url_for('baseapp.static',filename='datepicker/bootstrap-datepicker.js')}}"></script>
	<script src="{{url_for('baseapp.static',filename='select2/select2.js')}}"></script>

	<script>
		$(document).ready(function() {
		$('#datetimepicker').datetimepicker();
		$('#datepicker').datetimepicker({
                    pickTime: false });
        	$(".my_select2").select2({placeholder: "Select a State", allowClear: true});
        	$("a").tooltip({'selector': '','placement': 'bottom'});
		});
	</script>
{% endblock %}

{% block tail %}
{% endblock %}

  </body>
</html>
